pub struct TreeEditor<'a, P: Marshallable> { /* private fields */ }Expand description
An editor for a file in a breezy tree
Implementations
Sourceimpl<'a, P: Marshallable> TreeEditor<'a, P>
impl<'a, P: Marshallable> TreeEditor<'a, P>
Sourcepub fn from_env(
tree: &'a dyn MutableTree,
path: &Path,
allow_generated: bool,
allow_reformatting: Option<bool>,
) -> Result<Self, EditorError>
pub fn from_env( tree: &'a dyn MutableTree, path: &Path, allow_generated: bool, allow_reformatting: Option<bool>, ) -> Result<Self, EditorError>
Create a new editor, with preferences being read from the environment
Sourcepub fn new(
tree: &'a dyn MutableTree,
path: &Path,
allow_generated: bool,
allow_reformatting: bool,
) -> Result<Self, EditorError>
pub fn new( tree: &'a dyn MutableTree, path: &Path, allow_generated: bool, allow_reformatting: bool, ) -> Result<Self, EditorError>
Create a new editor