control_files_in_root

Function control_files_in_root 

pub fn control_files_in_root(tree: &dyn Tree, subpath: &Path) -> bool
Check whether the package in a tree has control files in the root, rather than in debian/.