Module lintian

Module lintian 

Lintian data structures and utilities

Structs

PolicyRelease
A release of the Debian Policy
StandardsVersion
A version of the Debian Policy

Constants

LINTIAN_DATA_PATH
The path to the Lintian data directory
RELEASE_DATES_PATH_NEW
The path to the Lintian release dates file (new name)
RELEASE_DATES_PATH_OLD
The path to the Lintian release dates file (old name)

Functions

iter_standards_versions
Returns an iterator over all known standards versions
iter_standards_versions_opt
Returns an iterator over all known standards versions Returns None if neither releases.json nor release-dates.json can be found
latest_standards_version
Returns the latest standards version
latest_standards_version_opt
Returns the latest standards version Returns None if release data files are not available