Module patches

Module patches 

Functions for working with patches in a Debian package.

Constants

DEFAULT_DEBIAN_PATCHES_DIR
Default name of the patches directory.

Functions

add_patch
Add a new patch.
find_patch_base
Find the base revision to apply patches to.
find_patches_branch
Find the branch that is used to track patches.
find_patches_directory
Find the patches directory for a package
move_upstream_changes_to_patch
Move upstream changes to patch.
read_quilt_patches
Read quilt patches from a directory.
rules_find_patches_directory
Find the name of the patches directory in a debian/rules file
tree_non_patches_changes
Check if a Debian tree has changes vs upstream tree.
tree_patches_directory
Find the name of the patches directory.
upstream_with_applied_patches
Get the upstream tree with patches applied.