Lintian data structures and utilities
Structs
- Policy
Release - A release of the Debian Policy
- Standards
Version - A version of the Debian Policy
Constants
- LINTIAN_
DATA_ PATH - The path to the Lintian data directory
- RELEASE_
DATES_ PATH_ NEW - The path to the Lintian release dates file (new name)
- RELEASE_
DATES_ PATH_ OLD - The path to the Lintian release dates file (old name)
Functions
- iter_
standards_ versions - Returns an iterator over all known standards versions
- iter_
standards_ versions_ opt - Returns an iterator over all known standards versions Returns None if neither releases.json nor release-dates.json can be found
- latest_
standards_ version - Returns the latest standards version
- latest_
standards_ version_ opt - Returns the latest standards version Returns None if release data files are not available