Functions for working with patches in a Debian package.
Constants
- DEFAULT_
DEBIAN_ PATCHES_ DIR - Default name of the patches directory.
Functions
- add_
patch - Add a new patch.
- find_
patch_ base - Find the base revision to apply patches to.
- find_
patches_ branch - Find the branch that is used to track patches.
- find_
patches_ directory - Find the patches directory for a package
- move_
upstream_ changes_ to_ patch - Move upstream changes to patch.
- read_
quilt_ patches - Read quilt patches from a directory.
- rules_
find_ patches_ directory - Find the name of the patches directory in a debian/rules file
- tree_
non_ patches_ changes - Check if a Debian tree has changes vs upstream tree.
- tree_
patches_ directory - Find the name of the patches directory.
- upstream_
with_ applied_ patches - Get the upstream tree with patches applied.